==========================
django-password-validation
==========================

.. image:: https://secure.travis-ci.org/orcasgit/django-password-validation.png?branch=master
   :target: http://travis-ci.org/orcasgit/django-password-validation
   :alt: Test status
.. image:: https://coveralls.io/repos/orcasgit/django-password-validation/badge.png?branch=master
   :target: https://coveralls.io/r/orcasgit/django-password-validation
   :alt: Test coverage
.. image:: https://readthedocs.org/projects/django-password-validation/badge/?version=latest
   :target: https://readthedocs.org/projects/django-password-validation/?badge=latest
   :alt: Documentation Status
.. image:: https://badge.fury.io/py/django-password-validation.svg
   :target: https://pypi.python.org/pypi/django-password-validation
   :alt: Latest version

A backport of the `password validation system`_ from Django 1.9 (by Erik
Romijn), for use on earlier Django versions.

Password validation isn't hard to implement yourself, but if you use this
backport you'll be writing your validators to the same API that will be
built-in to upcoming Django versions.

``django-password-validation`` supports `Django`_ 1.8.2 and later on Python
2.7, 3.3, 3.4, pypy, and pypy3.

.. _Django: http://www.djangoproject.com/
.. _password validation system: https://docs.djangoproject.com/en/dev/topics/auth/passwords/#password-validation


Getting Help
============

Documentation for django-password-validation is available at
https://django-password-validation.readthedocs.org/

This app is available on `PyPI`_ and can be installed with ``pip install
django-password-validation``.

.. _PyPI: https://pypi.python.org/pypi/django-password-validation/


Contributing
============

See the `contributing docs`_.

.. _contributing docs: https://github.com/orcasgit/django-password-validation/blob/master/CONTRIBUTING.rst

